%define pkgname sphinx
Name:          python-sphinx
Epoch:         2
Version:       7.4.5
Release:       1mamba
Summary:       Python documentation generator
Group:         System/Libraries/Python
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.sphinx-doc.org/en/master/
Source:        https://pypi.debian.net/Sphinx/sphinx-%{version}.tar.gz
License:       BSD
## AUTOBUILDREQ-BEGIN
BuildRequires: (python3.11dist(alabaster) >= 0.7.14 with python3.11dist(alabaster) < 0.8)
BuildRequires: libpython311-devel
BuildRequires: python3.11dist(babel)
BuildRequires: python3.11dist(docutils)
BuildRequires: python3.11dist(imagesize)
BuildRequires: python3.11dist(jinja2)
BuildRequires: python3.11dist(packaging)
BuildRequires: python3.11dist(pygments)
BuildRequires: python3.11dist(requests)
BuildRequires: python3.11dist(snowballstemmer)
BuildRequires: python3.11dist(sphinxcontrib-applehelp)
BuildRequires: python3.11dist(sphinxcontrib-devhelp)
BuildRequires: python3.11dist(sphinxcontrib-htmlhelp)
BuildRequires: python3.11dist(sphinxcontrib-jsmath)
BuildRequires: python3.11dist(sphinxcontrib-qthelp)
BuildRequires: python3.11dist(sphinxcontrib-serializinghtml)
## AUTOBUILDREQ-END
BuildRequires: libpython3-devel >= 3.11.5

%description
Sphinx is a tool that makes it easy to create intelligent and beautiful documentation for Python projects (or other documents consisting of multiple reStructuredText sources), written by Georg Brandl.
It was originally created to translate the new Python documentation, but has now been cleaned up in the hope that it will be useful to many other projects.
Sphinx uses reStructuredText as its markup language, and many of its strengths come from the power and straightforwardness of reStructuredText and its parsing and translating suite, the Docutils.
Although it is still under constant development, the following features are already present, work fine and can be seen "in action" in the Python docs:

* Output formats: HTML (including Windows HTML Help), plain text and LaTeX, for printable PDF versions
* Extensive cross-references: semantic markup and automatic links for functions, classes, glossary terms and similar pieces of information
* Hierarchical structure: easy definition of a document tree, with automatic links to siblings, parents and children
* Automatic indices: general index as well as a module index
* Code handling: automatic highlighting using the Pygments highlighter
* Various extensions are available, e.g. for automatic testing of snippets and inclusion of appropriately formatted docstrings.

%if 0%{?with_pyver}
%if "%{?with_pyver}" == "3"
%define py_requires_append \
Provides:      python-Sphinx \
Obsoletes:     python-Sphinx < 2:6.1.3 \
Provides:      python-sphinx-py310 \
Obsoletes:     python-sphinx-py310 < 2:7.2.6-1mamba \
Provides:      python-Sphinx-py310 \
Obsoletes:     python-Sphinx-py310 < 2:6.1.3-3mamba \
Obsoletes:     python-Sphinx-py36 < 3.5.4-2mamba \
Obsoletes:     python-Sphinx-py3 < 2:6.1.3
%endif
%pyver_package
%endif

%prep
%setup -q -n sphinx-%{version}

%build
CFLAGS="%{optflags}" %{__python} -m build --no-isolation --wheel

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%{__python} -m installer --destdir=%{buildroot} dist/*.whl

%if "%{?with_pyver}" != "3"
# Rename any conflicting file outside of python site packages tree
for f in %{_bindir}/sphinx-{apidoc,autogen,build,quickstart}; do
   mv %{buildroot}${f}{,-%{?pyappend}}
done
%else
# Add -3 suffix as often searched for python3 version
for f in %{_bindir}/sphinx-{apidoc,autogen,build,quickstart}; do
   ln -s ${f} %{buildroot}${f}-3
done
%endif

%files %{?pyappend}
%defattr(-,root,root)
%{_bindir}/sphinx-apidoc*
%{_bindir}/sphinx-autogen*
%{_bindir}/sphinx-build*
%{_bindir}/sphinx-quickstart*
%dir %{python_sitelib}/%{pkgname}-%{version}.dist-info
%{python_sitelib}/%{pkgname}-%{version}.dist-info/*
%dir %{python_sitelib}/%{pkgname}
%{python_sitelib}/%{pkgname}/*

%changelog
* Wed Jul 17 2024 Automatic Build System <autodist@openmamba.org> 7.4.5-1mamba
- automatic version update by autodist

* Tue Jul 16 2024 Automatic Build System <autodist@openmamba.org> 7.4.4-1mamba
- automatic version update by autodist

* Fri Apr 19 2024 Automatic Build System <autodist@openmamba.org> 7.3.7-1mamba
- automatic version update by autodist

* Thu Apr 18 2024 Automatic Build System <autodist@openmamba.org> 7.3.6-1mamba
- automatic version update by autodist

* Wed Apr 17 2024 Automatic Build System <autodist@openmamba.org> 7.3.5-1mamba
- automatic version update by autodist

* Thu Mar 14 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 7.2.6-1mamba
- update to 7.2.6

* Sat Sep 30 2023 Automatic Build System <autodist@mambasoft.it> 7.0.1-2mamba
- rebuilt with python3 = 3.11.5

* Sat May 13 2023 Automatic Build System <autodist@mambasoft.it> 7.0.1-1mamba
- automatic version update by autodist

* Sun Apr 30 2023 Automatic Build System <autodist@mambasoft.it> 7.0.0-1mamba
- automatic version update by autodist

* Wed Apr 26 2023 Automatic Build System <autodist@mambasoft.it> 6.2.1-1mamba
- automatic version update by autodist

* Mon Apr 24 2023 Automatic Build System <autodist@mambasoft.it> 6.2.0-1mamba
- automatic version update by autodist

* Sat Mar 25 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.3-4mamba
- -py310: provide python-Sphinx for legacy

* Thu Mar 23 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.3-3mamba
- rename from python-Sphinx to python-sphinx; fix provides and obsoletes with python-sphinx-py3

* Tue Mar 07 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 6.1.3-2mamba
- fix obsoleting python-Sphinx

* Mon Mar 06 2023 Automatic Build System <autodist@mambasoft.it> 6.1.3-1mamba
- automatic version update by autodist

* Wed Jul 27 2022 Automatic Build System <autodist@mambasoft.it> 5.1.1-1mamba
- automatic version update by autodist

* Mon Jul 25 2022 Automatic Build System <autodist@mambasoft.it> 5.1.0-1mamba
- automatic version update by autodist

* Fri Jun 17 2022 Automatic Build System <autodist@mambasoft.it> 5.0.2-1mamba
- automatic version update by autodist

* Sat Jun 04 2022 Automatic Build System <autodist@mambasoft.it> 5.0.1-1mamba
- automatic version update by autodist

* Mon May 30 2022 Automatic Build System <autodist@mambasoft.it> 5.0.0-1mamba
- automatic version update by autodist

* Mon Mar 28 2022 Automatic Build System <autodist@mambasoft.it> 4.5.0-1mamba
- automatic version update by autodist

* Mon Jan 17 2022 Automatic Build System <autodist@mambasoft.it> 4.4.0-1mamba
- automatic version update by autodist

* Mon Dec 20 2021 Automatic Build System <autodist@mambasoft.it> 4.3.2-1mamba
- automatic version update by autodist

* Sat Nov 27 2021 Automatic Build System <autodist@mambasoft.it> 4.3.1-1mamba
- automatic version update by autodist

* Thu Nov 11 2021 Automatic Build System <autodist@mambasoft.it> 4.3.0-1mamba
- automatic version update by autodist

* Sun Sep 12 2021 Automatic Build System <autodist@mambasoft.it> 4.2.0-1mamba
- automatic version update by autodist

* Tue Jul 27 2021 Automatic Build System <autodist@mambasoft.it> 4.1.2-1mamba
- automatic version update by autodist

* Thu Jul 15 2021 Automatic Build System <autodist@mambasoft.it> 4.1.1-1mamba
- automatic version update by autodist

* Mon Jul 12 2021 Automatic Build System <autodist@mambasoft.it> 4.1.0-1mamba
- automatic version update by autodist

* Tue Jul 06 2021 Automatic Build System <autodist@mambasoft.it> 4.0.3-1mamba
- automatic version update by autodist

* Sun May 30 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 4.0.2-1mamba
- update to 4.0.2

* Tue May 11 2021 Automatic Build System <autodist@mambasoft.it> 4.0.1-1mamba
- automatic version update by autodist

* Mon May 10 2021 Automatic Build System <autodist@mambasoft.it> 4.0.0-1mamba
- automatic version update by autodist

* Wed Apr 14 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 3.5.4-2mamba
- rebuilt with distdeps

* Mon Apr 12 2021 Automatic Build System <autodist@mambasoft.it> 3.5.4-1mamba
- automatic version update by autodist

* Sun Mar 21 2021 Automatic Build System <autodist@mambasoft.it> 3.5.3-1mamba
- automatic version update by autodist

* Sun Mar 07 2021 Automatic Build System <autodist@mambasoft.it> 3.5.2-1mamba
- automatic version update by autodist

* Mon Feb 22 2021 Automatic Build System <autodist@mambasoft.it> 3.5.1-1mamba
- automatic version update by autodist

* Sun Nov 29 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.1-6mamba
- require sphinxcontrib packages with -py3 suffix

* Sat Nov 28 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.1-5mamba
- rebuilt with python3

* Tue Apr 28 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.1-4mamba
- require python-sphinxcontrib-websupport-py36

* Tue Apr 28 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.1-3mamba
- require python-sphinx_rtd_theme-py36

* Sun Jan 05 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.1-2mamba
- require python-commonmark-py36

* Mon Dec 30 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.1-1mamba
- update to 2.3.1

* Thu May 16 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.1-1mamba
- update to 2.0.1

* Thu Mar 28 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.5-1mamba
- update to 1.8.5

* Sun Sep 09 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.9-2mamba
- require python-setuptools package for target python version

* Thu Sep 06 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.7.9-1mamba
- update to 1.7.9

* Sun Oct 02 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.6-2mamba
- require python-imagesize

* Mon Sep 19 2016 Automatic Build System <autodist@mambasoft.it> 1.4.6-1mamba
- automatic update by autodist

* Sat Aug 20 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.1-4mamba
- rename py3 conflicting binaries

* Sat May 16 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.1-3mamba
- added python3 subpackage

* Sun Mar 29 2015 Davide Madrisan <davide.madrisan@gmail.com> 1.3.1-2mamba
- add some missing requirements

* Fri Mar 20 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 1.3.1-1mamba
- update to 1.3.1

* Thu Jan 29 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.3-1mamba
- revert to stable version

* Sun Dec 07 2014 Automatic Build System <autodist@mambasoft.it> 1.3b2-1mamba
- automatic update by autodist

* Tue Nov 04 2014 Automatic Build System <autodist@mambasoft.it> 1.3b1-1mamba
- automatic update by autodist

* Sun Dec 15 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2b2-2mamba
- require python-markupsafe

* Sat Sep 21 2013 Automatic Build System <autodist@mambasoft.it> 1.2b2-1mamba
- automatic update by autodist

* Mon Jun 10 2013 Automatic Build System <autodist@mambasoft.it> 1.2b1-1mamba
- automatic version update by autodist

* Sat May 25 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1.3-2mamba
- revert to stable release 1.1.3 (try building python-bzr)

* Fri May 17 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2b1-2mamba
- python 2.7 mass rebuild

* Thu Apr 04 2013 Automatic Build System <autodist@mambasoft.it> 1.2b1-1mamba
- automatic version update by autodist

* Tue Aug 07 2012 Automatic Build System <autodist@mambasoft.it> 1.1.3-1mamba
- automatic version update by autodist

* Tue Sep 27 2011 Automatic Build System <autodist@mambasoft.it> 1.0.8-1mamba
- automatic version update by autodist

* Wed Feb 02 2011 Automatic Build System <autodist@mambasoft.it> 1.0.7-1mamba
- automatic update by autodist

* Tue Jan 11 2011 Automatic Build System <autodist@mambasoft.it> 1.0.6-1mamba
- automatic update by autodist

* Fri Nov 19 2010 Automatic Build System <autodist@mambasoft.it> 1.0.5-1mamba
- automatic update by autodist

* Wed Sep 29 2010 Automatic Build System <autodist@mambasoft.it> 1.0.4-1mamba
- automatic update by autodist

* Wed Jul 28 2010 Automatic Build System <autodist@mambasoft.it> 1.0.1-1mamba
- automatic update by autodist

* Sat Jan 02 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.3-1mamba
- package created by autospec
